# PDO

**PDO** - PHP Data Objects, унифицированный слой (**API**) для доступа к разным СУБД. **PDO** является объектно-ориентированной библиотекой, которая 
содержит несколько классов для работы с СУБД:
- **PDO** - Соединение с СУБД, которое позволяет выполнять запросы.
- **PDOStatement** - Тот или иной результат работы запроса, например строки данных после выполнения `SELECT`.

## Инициализация соединения.

Для доступа к СУБД нужны следующие параметры:
- **Хост**. Современные СУБД зачастую являются сетевыми. Таким образом нужно знать адрес компьютера в сети.
- **Имя БД**. Одновременно в СУБД может быть несколько баз данных. 
- **Имя пользователя** и **Пароль**. 

```php
<?php
$dbh = new PDO('mysql:host=localhost;dbname=test', $user, $pass);
```

Первым параметром *конструктора* **PDO** является так называемый **DSN** - строка, которая определяет тип СУБД, хост и имя базы. В зависимости
от типа СУБД PDO подключает тот или иной драйвер СУБД и передает в него нужные настройки.

В случае успешного соединения (в противном случае происходит исключение `PDOException`) можно работать с данными в СУБД:

```php
<?php
try {
    $dbh = new PDO('mysql:host=localhost;dbname=test', $user, $pass);
    foreach($dbh->query('SELECT * from FOO') as $row) {
        print_r($row);
    }
    $dbh = null;
} catch (PDOException $e) {
    print "Error!: " . $e->getMessage() . "<br/>";
    die();
}
```
